@@ -16,27 +16,21 @@
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
-#------------------------------------------------------------------------
-#
-# $Id: Exception.pm,v 2.66 2006/01/30 20:04:49 abw Exp $
+# REVISION
+#   $Id: Exception.pm,v 2.69 2006/05/30 17:01:28 abw Exp $
 #
 #========================================================================
 
-
 package Template::Exception;
 
-require 5.005;
-
 use strict;
-use vars qw( $VERSION );
-
+use warnings;
 use constant TYPE  => 0;
 use constant INFO  => 1;
 use constant TEXT  => 2;
 use overload q|""| => "as_string", fallback => 1;
 
-
-$VERSION = sprintf("%d.%02d", q$Revision: 2.66 $ =~ /(\d+)\.(\d+)/);
+our $VERSION = 2.69;
 
 
 #------------------------------------------------------------------------
@@ -228,13 +222,13 @@ L<http://wardley.org/|http://wardley.org/>
 
 =head1 VERSION
 
-2.66, distributed as part of the
-Template Toolkit version 2.15, released on 26 May 2006.
+2.69, distributed as part of the
+Template Toolkit version 2.18, released on 09 February 2007.
 
 =head1 COPYRIGHT
 
-  Copyright (C) 1996-2006 Andy Wardley.  All Rights Reserved.
-  Copyright (C) 1998-2002 Canon Research Centre Europe Ltd.
+  Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
+
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
