@@ -8,33 +8,30 @@
 #   and instantiated via the USE directive.
 #
 # AUTHOR
-#   Andy Wardley   <abw@kfs.org>
+#   Andy Wardley   <abw@wardley.org>
 #
 # COPYRIGHT
-#   Copyright (C) 1996-2000 Andy Wardley.  All Rights Reserved.
+#   Copyright (C) 1996-2006 Andy Wardley.  All Rights Reserved.
 #   Copyright (C) 1998-2000 Canon Research Centre Europe Ltd.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
-#----------------------------------------------------------------------------
-#
-# $Id: Plugin.pm,v 2.67 2006/01/30 20:04:54 abw Exp $
+# REVISION
+#   $Id: Plugin.pm,v 2.70 2006/05/30 17:01:29 abw Exp $
 #
 #============================================================================
 
 package Template::Plugin;
 
-require 5.004;
-
 use strict;
-use Template::Base;
+use warnings;
+use base 'Template::Base';
 
-use vars qw( $VERSION $DEBUG $ERROR $AUTOLOAD );
-use base qw( Template::Base );
-
-$VERSION = sprintf("%d.%02d", q$Revision: 2.67 $ =~ /(\d+)\.(\d+)/);
-$DEBUG   = 0;
+our $VERSION = 2.70;
+our $DEBUG   = 0 unless defined $DEBUG;
+our $ERROR   = '';
+our $AUTOLOAD;
 
 
 #========================================================================
@@ -383,13 +380,13 @@ L<http://wardley.org/|http://wardley.org/>
 
 =head1 VERSION
 
-2.67, distributed as part of the
-Template Toolkit version 2.15, released on 26 May 2006.
+2.7, distributed as part of the
+Template Toolkit version 2.18, released on 09 February 2007.
 
 =head1 COPYRIGHT
 
-  Copyright (C) 1996-2006 Andy Wardley.  All Rights Reserved.
-  Copyright (C) 1998-2002 Canon Research Centre Europe Ltd.
+  Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
+
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
