@@ -6,34 +6,31 @@
 #   Template Toolkit plugin to implement a basic String object.
 #
 # AUTHOR
-#   Andy Wardley   <abw@kfs.org>
+#   Andy Wardley   <abw@wardley.org>
 #
 # COPYRIGHT
-#   Copyright (C) 2001 Andy Wardley.  All Rights Reserved.
+#   Copyright (C) 2001-2006 Andy Wardley.  All Rights Reserved.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
 # REVISION
-#   $Id: String.pm,v 2.37 2006/01/30 20:05:48 abw Exp $
+#   $Id: String.pm,v 2.40 2006/05/30 17:01:36 abw Exp $
 #
 #============================================================================
 
 package Template::Plugin::String;
 
-require 5.004;
-
 use strict;
-use Template::Plugin;
+use warnings;
+use base 'Template::Plugin';
 use Template::Exception;
 
-use base qw( Template::Plugin );
-use vars qw( $VERSION $ERROR);
 use overload q|""| => "text",
              fallback => 1;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 2.37 $ =~ /(\d+)\.(\d+)/);
-$ERROR   = '';
+our $VERSION = 2.40;
+our $ERROR   = '';
 
 *centre  = \*center;
 *append  = \*push;
@@ -810,13 +807,13 @@ L<http://wardley.org/|http://wardley.org/>
 
 =head1 VERSION
 
-2.37, distributed as part of the
-Template Toolkit version 2.15, released on 26 May 2006.
+2.4, distributed as part of the
+Template Toolkit version 2.18, released on 09 February 2007.
 
 =head1 COPYRIGHT
 
-  Copyright (C) 1996-2006 Andy Wardley.  All Rights Reserved.
-  Copyright (C) 1998-2002 Canon Research Centre Europe Ltd.
+  Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
+
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
