@@ -7,18 +7,17 @@
 #   instantiation of plugin objects.
 #
 # AUTHORS
-#   Andy Wardley <abw@kfs.org>
+#   Andy Wardley <abw@wardley.org>
 #
 # COPYRIGHT
-#   Copyright (C) 1996-2000 Andy Wardley.  All Rights Reserved.
+#   Copyright (C) 1996-2006 Andy Wardley.  All Rights Reserved.
 #   Copyright (C) 1998-2000 Canon Research Centre Europe Ltd.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
-#----------------------------------------------------------------------------
-#
-# $Id: Plugins.pm,v 2.74 2006/01/30 20:04:54 abw Exp $
+# REVISION
+#   $Id: Plugins.pm,v 2.77 2006/05/30 17:01:29 abw Exp $
 #
 #============================================================================
 
@@ -29,7 +28,7 @@ use warnings;
 use base 'Template::Base';
 use Template::Constants;
 
-our $VERSION = sprintf("%d.%02d", q$Revision: 2.74 $ =~ /(\d+)\.(\d+)/);
+our $VERSION = 2.77;
 our $DEBUG   = 0 unless defined $DEBUG;
 our $PLUGIN_BASE = 'Template::Plugin';
 our $STD_PLUGINS = {
@@ -46,11 +45,13 @@ our $STD_PLUGINS = {
     'html'       => 'Template::Plugin::HTML',
     'image'      => 'Template::Plugin::Image',
     'iterator'   => 'Template::Plugin::Iterator',
+    'latex'      => 'Template::Plugin::Latex',
     'pod'        => 'Template::Plugin::Pod',
     'table'      => 'Template::Plugin::Table',
     'url'        => 'Template::Plugin::URL',
     'view'       => 'Template::Plugin::View',
     'wrap'       => 'Template::Plugin::Wrap',
+    'xml'        => 'Template::Plugin::XML',
     'xmlstyle'   => 'Template::Plugin::XML::Style',
 };
 
@@ -864,13 +865,13 @@ L<http://wardley.org/|http://wardley.org/>
 
 =head1 VERSION
 
-2.74, distributed as part of the
-Template Toolkit version 2.15, released on 26 May 2006.
+2.77, distributed as part of the
+Template Toolkit version 2.18, released on 09 February 2007.
 
 =head1 COPYRIGHT
 
-  Copyright (C) 1996-2006 Andy Wardley.  All Rights Reserved.
-  Copyright (C) 1998-2002 Canon Research Centre Europe Ltd.
+  Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
+
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
