@@ -22,29 +22,27 @@
 #    view.print(hash3) %] or [% view.print(hash1, hash2, hash3, { }) %]
 #
 # REVISION
-#   $Id: View.pm,v 2.8 2002/04/15 15:53:37 abw Exp $
+#   $Id: View.pm,v 2.10 2006/05/30 17:01:29 abw Exp $
 #
 #============================================================================
 
 package Template::View;
 
-require 5.004;
-
 use strict;
-use vars qw( $VERSION $DEBUG $AUTOLOAD @BASEARGS $MAP );
-use base qw( Template::Base );
+use warnings;
+use base 'Template::Base';
 
-$VERSION  = sprintf("%d.%02d", q$Revision: 2.8 $ =~ /(\d+)\.(\d+)/);
-$DEBUG    = 0 unless defined $DEBUG;
-@BASEARGS = qw( context );
-$MAP = {
+our $VERSION  = 2.91;
+our $DEBUG    = 0 unless defined $DEBUG;
+our @BASEARGS = qw( context );
+our $AUTOLOAD;
+our $MAP = {
     HASH    => 'hash',
     ARRAY   => 'list',
     TEXT    => 'text',
     default => '',
 };
 
-#$DEBUG = 1;    
 
 #------------------------------------------------------------------------
 # _init(\%config)
@@ -202,11 +200,11 @@ sub print {
     # if final config hash is specified then create a clone and delegate to it
     # NOTE: potential problem when called print(\%data_hash1, \%data_hash2);
     if ((scalar @_ > 1) && (ref $_[-1] eq 'HASH')) {
-	my $cfg = pop @_;
-	my $clone = $self->clone($cfg)
-	    || return;
-	return $clone->print(@_) 
-	    || $self->error($clone->error());
+        my $cfg = pop @_;
+        my $clone = $self->clone($cfg)
+            || return;
+        return $clone->print(@_) 
+            || $self->error($clone->error());
     }
     my ($item, $type, $template, $present);
     my $method = $self->{ method };
@@ -215,45 +213,43 @@ sub print {
     
     # print each argument
     foreach $item (@_) {
-	my $newtype;
-
-	if (! ($type = ref $item)) {
-	    # non-references are TEXT
-	    $type = 'TEXT';
-	    $template = $map->{ $type };
-	}
-	elsif (! defined ($template = $map->{ $type })) {
-	    # no specific map entry for object, maybe it implements a 
-	    # 'present' (or other) method?
-#	    $self->DEBUG("determining if $item can $method\n") if $DEBUG;
-	    if ( $method && UNIVERSAL::can($item, $method) ) {
-		$self->DEBUG("Calling \$item->$method\n") if $DEBUG;
-		$present = $item->$method($self);	## call item method
-		# undef returned indicates error, note that we expect 
-		# $item to have called error() on the view
-		return unless defined $present;
-		$output .= $present;
-		next;					## NEXT
-	    }   
-	    elsif ( UNIVERSAL::isa($item, 'HASH' ) 
-		   && defined($newtype = $item->{$method})
-		   && defined($template = $map->{"$method=>$newtype"})) {
-	    }
-	    elsif ( defined($newtype)
-		 && defined($template = $map->{"$method=>*"}) ) {
-		$template =~ s/\*/$newtype/;
+        my $newtype;
+        
+        if (! ($type = ref $item)) {
+            # non-references are TEXT
+            $type = 'TEXT';
+            $template = $map->{ $type };
+        }
+        elsif (! defined ($template = $map->{ $type })) {
+            # no specific map entry for object, maybe it implements a 
+            # 'present' (or other) method?
+            if ( $method && UNIVERSAL::can($item, $method) ) {
+                $present = $item->$method($self);	## call item method
+                # undef returned indicates error, note that we expect 
+                # $item to have called error() on the view
+                return unless defined $present;
+                $output .= $present;
+                next;					## NEXT
+            }   
+            elsif ( UNIVERSAL::isa($item, 'HASH' ) 
+                    && defined($newtype = $item->{$method})
+                    && defined($template = $map->{"$method=>$newtype"})) {
+            }
+            elsif ( defined($newtype)
+                    && defined($template = $map->{"$method=>*"}) ) {
+                $template =~ s/\*/$newtype/;
             }    
-	    elsif (! ($template = $map->{ default }) ) {
-		# default not defined, so construct template name from type
-		($template = $type) =~ s/\W+/_/g;
-	    }
-	}
+            elsif (! ($template = $map->{ default }) ) {
+                # default not defined, so construct template name from type
+                ($template = $type) =~ s/\W+/_/g;
+            }
+        }
 #	else {
 #	    $self->DEBUG("defined map type for $type: $template\n");
 #	}
-	$self->DEBUG("printing view '", $template || '', "', $item\n") if $DEBUG;
-	$output .= $self->view($template, $item)
-	    if $template;
+        $self->DEBUG("printing view '", $template || '', "', $item\n") if $DEBUG;
+        $output .= $self->view($template, $item)
+            if $template;
     }
     return $output;
 }
@@ -731,10 +727,6 @@ TODO
 
 Andy Wardley E<lt>abw@kfs.orgE<gt>
 
-=head1 REVISION
-
-$Revision: 2.8 $
-
 =head1 COPYRIGHT
 
 Copyright (C) 2000 Andy Wardley.  All Rights Reserved.
